using System.Collections;
using System.Reflection;
using System.Windows;
using System.Windows.Interactivity;
using Infragistics.Windows.DataPresenter;

namespace xamDataGridFixedRowsIssue
{
    public class XamDataGridFixedRowBehaviour : Behavior<XamDataGrid>
    {
        #region dependency properties

        public static readonly DependencyProperty DataSourceProperty =
            DependencyProperty.Register("DataSource", typeof(IList), typeof(XamDataGridFixedRowBehaviour), new PropertyMetadata(default(IList), DataSourceChanged));

        public IList DataSource
        {
            get { return (IList)GetValue(DataSourceProperty); }
            set { SetValue(DataSourceProperty, value); }
        }

        public static readonly DependencyProperty FixedRowFieldNameProperty =
            DependencyProperty.Register("FixedRowFieldName", typeof(string), typeof(XamDataGridFixedRowBehaviour), new PropertyMetadata(default(string)));

        public string FixedRowFieldName
        {
            get { return (string)GetValue(FixedRowFieldNameProperty); }
            set { SetValue(FixedRowFieldNameProperty, value); }
        }

        #endregion

        private static void DataSourceChanged(DependencyObject d, DependencyPropertyChangedEventArgs e)
        {
            //make sure if the data source is valid
            IList dataSource = e.NewValue as IList;
            if (dataSource == null) return;

            //ensure if the name of the field to lookup has been supplied
            XamDataGridFixedRowBehaviour sender = d as XamDataGridFixedRowBehaviour;
            if (sender == null) return;
            if (string.IsNullOrWhiteSpace(sender.FixedRowFieldName)) return;

            XamDataGrid grid = sender.AssociatedObject;
            int totalRows = grid.ViewableRecords.Count;

            for (int i = totalRows - 1; i >= 0; i--)
            {
                object item = dataSource[i];
                PropertyInfo propertyInfo = item.GetType().GetProperty(sender.FixedRowFieldName);
                object propertyValue = propertyInfo.GetValue(item, null);
                if (propertyValue != null)
                {
                    bool isSummaryRow;
                    if (bool.TryParse(propertyValue.ToString(), out isSummaryRow))
                    {
                        if (isSummaryRow)
                        {
                            grid.ViewableRecords[i].FixedLocation = FixedRecordLocation.FixedToBottom;
                        }
                    }
                }
            }
        }
    }
}